==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/magnet/dialogs_es.lua <==

dialogId("pap-v-ha", "font_big", "Look. Another energy source.")
dialogStr("Mira. Otra fuente de energía.")


dialogId("pap-m-magnet", "font_small", "Don`t worry. This magnet is here only to hinder us.")
dialogStr("No te preocupes. Este imán solo está aquí para ser un obstáculo.")


dialogId("pap-v-potrebovat", "font_big", "I think we are going to need it.")
dialogStr("Creo que lo vamos a necesitar.")


dialogId("pap-m-zvlastni", "font_small", "This is a very strange object.")
dialogStr("Este es un objeto muy extraño.")


dialogId("pap-v-prekvapeni", "font_big", "I think that UFO is going to be full of such surprises.")
dialogStr("Creo que ese OVNI va a estar lleno de esas sorpresas.")


dialogId("pap-m-teorie", "font_small", "Stop developing your theories and start solving.")
dialogStr("Intenta solucionar algo en lugar de desarrollar tus teorías.")


dialogId("pap-m-radio", "font_small", "This looks like a radio.")
dialogStr("Esto parece una radio.")


dialogId("pap-v-radio", "font_big", "How could a radio get here?")
dialogStr("¿Qué hace una radio aquí?")


dialogId("pap-m-nechme", "font_small", "Let it be.")
dialogStr("Déjala ser.")


dialogId("pap-v-divny", "font_big", "This is a strange radio.")
dialogStr("Es una radio extraña.")


dialogId("pap-m-coje", "font_small", "What have we here?")
dialogStr("¿Qué tenemos aquí?")


dialogId("pap-m-pistole", "font_small", "It looks like a pistol to me.")
dialogStr("A mí me parece una pistola.")


dialogId("pap-v-laserova", "font_big", "Maybe it`s a laser weapon.")
dialogStr("Quizás es un arma láser.")


dialogId("pap-m-jejedno", "font_small", "It doesn`t matter. We don`t need it.")
dialogStr("No importa. No la necesitamos.")


dialogId("pap-v-nemir", "font_big", "Stop pointing at me with it!")
dialogStr("¡Deja de apuntarme con eso!")


dialogId("pap-m-nejde", "font_small", "As if you don`t know that you can`t turn objects in this game.")
dialogStr("Por si no lo sabías, no puedes doblar objetos en este juego.")


dialogId("pap-m-ocel", "font_small", "There are too many steel constructions here.")
dialogStr("Hay muchas construcciones de acero aquí.")


dialogId("pap-v-vufu", "font_big", "Don`t forget that we are inside of the flying saucer!")
dialogStr("¡No olvides que estamos dentro del platillo volador!")


dialogId("pap-m-naucit", "font_small", "Maybe I could learn how to manipulate these steel tubes.")
dialogStr("Quizás yo podría aprender como manipular esos tubos de acero.")


dialogId("pap-m-nepohnu", "font_small", "No, I can`t move it.")
dialogStr("No, no puedo moverlo.")


dialogId("pap-v-tesno", "font_big", "It`s quite tight here.")
dialogStr("Es muy apretado aquí.")


dialogId("pap-m-mraz", "font_small", "These magnets are giving me the creeps.")
dialogStr("Esos imanes me erizan las escamas.")


dialogId("pap-v-pole", "font_big", "This magnetic field probably has some invigorating effects.")
dialogStr("Probablemente este campo magnético tiene algunos efectos vigorizantes.")


dialogId("pap-m-nedobre", "font_small", "It`s doing me no good.")
dialogStr("No me hace nada de bien.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/magnet/dialogs_es.lua <==

dialogId("pap-v-ha", "font_big", "Look. Another energy source.")
dialogStr("Mira. Otra fuente de energía.")


dialogId("pap-m-magnet", "font_small", "Don’t worry. This magnet is here only to hinder us.")
dialogStr("No te preocupes. Este imán solo está aquí para ser un obstáculo.")


dialogId("pap-v-potrebovat", "font_big", "I think we are going to need it.")
dialogStr("Creo que lo vamos a necesitar.")


dialogId("pap-m-zvlastni", "font_small", "This is a very strange object.")
dialogStr("Este es un objeto muy extraño.")


dialogId("pap-v-prekvapeni", "font_big", "I think that UFO is going to be full of such surprises.")
dialogStr("Creo que ese OVNI va a estar lleno de esas sorpresas.")


dialogId("pap-m-teorie", "font_small", "Stop developing your theories and start solving.")
dialogStr("Intenta solucionar algo en lugar de desarrollar tus teorías.")


dialogId("pap-m-radio", "font_small", "This looks like a radio.")
dialogStr("Esto parece una radio.")


dialogId("pap-v-radio", "font_big", "How could a radio get here?")
dialogStr("¿Qué hace una radio aquí?")


dialogId("pap-m-nechme", "font_small", "Let it be.")
dialogStr("Déjala ser.")


dialogId("pap-v-divny", "font_big", "This is a strange radio.")
dialogStr("Es una radio extraña.")


dialogId("pap-m-coje", "font_small", "What have we here?")
dialogStr("¿Qué tenemos aquí?")


dialogId("pap-m-pistole", "font_small", "It looks like a pistol to me.")
dialogStr("A mí me parece una pistola.")


dialogId("pap-v-laserova", "font_big", "Maybe it’s a laser weapon.")
dialogStr("Quizás es un arma láser.")


dialogId("pap-m-jejedno", "font_small", "It doesn’t matter. We don’t need it.")
dialogStr("No importa. No la necesitamos.")


dialogId("pap-v-nemir", "font_big", "Stop pointing at me with it!")
dialogStr("¡Deja de apuntarme con eso!")


dialogId("pap-m-nejde", "font_small", "As if you don’t know that you can’t turn objects in this game.")
dialogStr("Por si no lo sabías, no puedes doblar objetos en este juego.")


dialogId("pap-m-ocel", "font_small", "There are too many steel constructions here.")
dialogStr("Hay muchas construcciones de acero aquí.")


dialogId("pap-v-vufu", "font_big", "Don’t forget that we are inside of the flying saucer!")
dialogStr("¡No olvides que estamos dentro del platillo volador!")


dialogId("pap-m-naucit", "font_small", "Maybe I could learn how to manipulate these steel tubes.")
dialogStr("Quizás yo podría aprender como manipular esos tubos de acero.")


dialogId("pap-m-nepohnu", "font_small", "No, I can’t move it.")
dialogStr("No, no puedo moverlo.")


dialogId("pap-v-tesno", "font_big", "It’s quite tight here.")
dialogStr("Es muy apretado aquí.")


dialogId("pap-m-mraz", "font_small", "These magnets are giving me the creeps.")
dialogStr("Esos imanes me erizan las escamas.")


dialogId("pap-v-pole", "font_big", "This magnetic field probably has some invigorating effects.")
dialogStr("Probablemente este campo magnético tiene algunos efectos vigorizantes.")


dialogId("pap-m-nedobre", "font_small", "It’s doing me no good.")
dialogStr("No me hace nada de bien.")
